@@ -19,7 +19,7 @@ use strict;
 use warnings;
 
 use Spreadsheet::ParseExcel::Utility qw(ExcelFmt);
-our $VERSION = '0.44';
+our $VERSION = '0.59';
 
 my %hFmtDefault = (
     0x00 => '@',
@@ -105,6 +105,12 @@ sub FmtString {
       $oThis->FmtStringDef( $oBook->{Format}[ $oCell->{FormatNo} ]->{FmtIdx},
         $oBook );
 
+    # Special case for cells that use Lotus123 style leading
+    # apostrophe to designate text formatting.
+    if ( $oBook->{Format}[ $oCell->{FormatNo} ]->{Key123} ) {
+        $sFmtStr = '@';
+    }
+
     unless ( defined($sFmtStr) ) {
         if ( $oCell->{Type} eq 'Numeric' ) {
             if ( int( $oCell->{Val} ) != $oCell->{Val} ) {
@@ -142,13 +148,16 @@ sub ValFmt {
           ( ( defined $oCell->{Val} ) && ( $oCell->{Val} ne '' ) )
           ? $oThis->TextFmt( $oCell->{Val}, $oCell->{Code} )
           : '';
+
+        return $Dt;
     }
     else {
-        $Dt = $oCell->{Val};
+        $Dt      = $oCell->{Val};
+        $Flg1904 = $oBook->{Flg1904};
+        my $sFmtStr = $oThis->FmtString( $oCell, $oBook );
+
+        return ExcelFmt( $sFmtStr, $Dt, $Flg1904, $oCell->{Type} );
     }
-    $Flg1904 = $oBook->{Flg1904};
-    my $sFmtStr = $oThis->FmtString( $oCell, $oBook );
-    return ExcelFmt( $sFmtStr, $Dt, $Flg1904, $oCell->{Type} );
 }
 
 #------------------------------------------------------------------------------
@@ -199,7 +208,7 @@ Original author: Kawai Takanori kwitknr@cpan.org
 
 =head1 COPYRIGHT
 
-Copyright (c) 2009 John McNamara
+Copyright (c) 2009-2010 John McNamara
 
 Copyright (c) 2006-2008 Gabor Szabo
 
