@@ -19,7 +19,7 @@ use strict;
 use warnings;
 use Scalar::Util qw(weaken);
 
-our $VERSION = '0.50';
+our $VERSION = '0.59';
 
 ###############################################################################
 #
@@ -544,10 +544,13 @@ sub is_print_comments {
 #
 # Mapping between legacy method names and new names.
 #
-*sheetNo  = *sheet_num;
-*Cell     = *get_cell;
-*RowRange = *row_range;
-*ColRange = *col_range;
+{
+    no warnings;    # Ignore warnings about variables used only once.
+    *sheetNo  = *sheet_num;
+    *Cell     = *get_cell;
+    *RowRange = *row_range;
+    *ColRange = *col_range;
+}
 
 1;
 
@@ -561,7 +564,7 @@ Spreadsheet::ParseExcel::Worksheet - A class for Worksheets.
 
 =head1 SYNOPSIS
 
-See the documentation for Spreadsheet::ParseExcel.
+See the documentation for L<Spreadsheet::ParseExcel>.
 
 =head1 DESCRIPTION
 
@@ -607,7 +610,7 @@ The C<Spreadsheet::ParseExcel::Worksheet> class encapsulates the properties of a
 
 =head2 get_cell($row, $col)
 
-Return the L<"Cell"> object at row C<$row> and column C<$col> if it is defined. Otherwise returns undef.
+Return the L</Cell> object at row C<$row> and column C<$col> if it is defined. Otherwise returns undef.
 
     my $cell = $worksheet->get_cell($row, $col);
 
@@ -624,15 +627,6 @@ Returns a two-element list C<($min, $max)> containing the minimum and maximum of
     my ( $col_min, $col_max ) = $worksheet->col_range();
 
 
-=head2 col_range()
-
-The C<col_range()> method returns TODO.
-
-    my $col_range = $worksheet->col_range();
-
-Returns 0 if the property isn't set.
-
-
 =head2 get_name()
 
 The C<get_name()> method returns the name of the worksheet.
@@ -948,7 +942,7 @@ Original author: Kawai Takanori kwitknr@cpan.org
 
 =head1 COPYRIGHT
 
-Copyright (c) 2009 John McNamara
+Copyright (c) 2009-2010 John McNamara
 
 Copyright (c) 2006-2008 Gabor Szabo
 
